import { Box, Modal, Typography, Divider, Button } from "@mui/material";
import { useEffect, useState } from "react";
import { useSelector, useDispatch } from "react-redux";
import { RootState, AppDispatch } from "../../../redux/store/store";
import { deleteManager, fetchManagerList } from "../../../redux/slices/managerSlice";

type User = {
  id: number;
  name: string;
  email?: string;
  phone: string;
  registeredAddress?: string;
};

type Props = {
  open: boolean;
  setDeleteModal: (value: boolean) => void;
  id?: number;
  tableType?: "admin" | "manager";
};

const style = {
  position: "absolute",
  top: "50%",
  left: "50%",
  transform: "translate(-50%, -50%)",
  width: 400,
  bgcolor: "background.paper",
  borderRadius: 2,
  boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.15)",
  p: 4,
  display: "flex",
  flexDirection: "column",
  alignItems: "center",
  gap: 2,
};

export default function DeleteModal({ open, setDeleteModal, id, tableType }: Props) {
  const dispatch = useDispatch<AppDispatch>();
  const adminList = useSelector((state: RootState) => state.adminReducer.admins) || [];
  const managerList = useSelector((state: RootState) => state.managerReducer.managers) || [];

  const [selectedItem, setSelectedItem] = useState<User | null>(null);
  const [loading, setLoading] = useState(false);

  useEffect(() => {
    if (!id || !tableType) return;

    const dataList: User[] = tableType === "admin" ? adminList : managerList;
    const item = dataList.find((user) => user.id === id);
    setSelectedItem(item || null);
  }, [id, tableType, adminList, managerList]);



  

  const handleDelete = async () => {
    if (!id || !tableType) {
        return;
    }

    setLoading(true);
    try {
        let deleteResult;
        if (tableType === "managers") {
            deleteResult = await dispatch(deleteManager(id)).unwrap();
        }

        if (deleteResult) {
            await dispatch(fetchManagerList()); // Refresh list only if deletion is successful
        }
    } catch (error) {
        console.error("❌ Error while deleting:", error);
    } finally {
        setLoading(false);
        setDeleteModal(false);
    }
};


  return (
    <Modal open={open} onClose={() => setDeleteModal(false)} aria-labelledby="modal-title">
      <Box sx={style}>
        <Typography variant="h5" fontWeight="bold" sx={{ width: "100%", textAlign: "center" }}>
          Delete {tableType ? tableType.charAt(0).toUpperCase() + tableType.slice(1) : "User"}
        </Typography>

        <Divider sx={{ width: "100%" }} />

        {selectedItem ? (
          <Typography align="center">
            Are you sure you want to delete <b>{selectedItem.name}</b>?
          </Typography>
        ) : (
          <Typography align="center">No {tableType} found with this ID</Typography>
        )}

        <Box sx={{ display: "flex", gap: 2 }}>
          <Button variant="contained" color="error" onClick={handleDelete} disabled={loading}>
            {loading ? "Deleting..." : "Delete"}
          </Button>
          <Button variant="outlined" onClick={() => setDeleteModal(false)}>Cancel</Button>
        </Box>
      </Box>
    </Modal>
  );
}
