import React, { useState } from "react";
import { Box, Button, Typography, Modal, IconButton, TextField } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { useDispatch } from "react-redux";
import { toast } from "sonner";
import { addManager } from "../../redux/slices/managerSlice";

interface AddManagerModalProps {
  open: boolean;
  handleClose: () => void;
}

const AddManagerModal: React.FC<AddManagerModalProps> = ({ open, handleClose }) => {
  // State for input fields
  const [name, setName] = useState("");
  const [stationLocation, setStationLocation] = useState("");
  const [phone, setPhone] = useState("");
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");

  const roleId = 5; // Fixed role ID
  const roleName = "Peon"; // Required role name

  const dispatch = useDispatch();

  // Function to validate form inputs
  const validateInputs = () => {
    if (!name || !stationLocation || !phone || !email || !password) {
      toast.error("All fields are required.");
      return false;
    }

    const phoneRegex = /^[0-9]{6,14}$/;
    if (!phoneRegex.test(phone)) {
      toast.error("Phone number must be between 6 to 14 digits.");
      return false;
    }

    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    if (!emailRegex.test(email)) {
      toast.error("Enter a valid email address.");
      return false;
    }

    if (password.length < 6) {
      toast.error("Password must be at least 6 characters long.");
      return false;
    }

    return true;
  };

  // Handle form submission
  const handleSubmit = async () => {
    if (!validateInputs()) return;
  
    const managerData = {
      name,
      registeredAddress: stationLocation,
      phone,
      email,
      password,
      roleId,
      roleName, // ✅ Ensure roleName is correctly included
    };
  
    try {
      const response = await dispatch(addManager(managerData)).unwrap();
  
      
  
      // ✅ Ensure response contains expected data
      if (!response || !response.id) {
        throw new Error("Invalid response from server. ID is missing.");
      }
  
      // ✅ Show success message from API if available, fallback if not
      toast.success(response.message || "Manager added successfully!");
  
      resetForm();
      handleClose();
    } catch (error: any) {
      console.error("API Error:", error); // ✅ Log error for debugging
  
      // ✅ Handle both API errors and unexpected errors
      toast.error(
        error?.response?.data?.message || error.message || "Failed to add manager"
      );
    }
  };
  
  

  // Function to reset form fields
  const resetForm = () => {
    setName("");
    setStationLocation("");
    setPhone("");
    setEmail("");
    setPassword("");
  };

  return (
    <Modal open={open} onClose={handleClose} aria-labelledby="add-manager-modal">
      <Box
        sx={{
          position: "absolute",
          top: "50%",
          left: "50%",
          transform: "translate(-50%, -50%)",
          width: 400,
          bgcolor: "background.paper",
          boxShadow: 24,
          p: 3,
          borderRadius: 2,
        }}
      >
        {/* Modal Header */}
        <Box sx={{ display: "flex", justifyContent: "space-between", alignItems: "center" }}>
          <Typography variant="h6" fontWeight={600}>
            Add Manager
          </Typography>
          <IconButton onClick={handleClose}>
            <CloseIcon />
          </IconButton>
        </Box>

        <Box sx={{ borderBottom: "1px solid #ddd", my: 2 }} />

        {/* Input Fields */}
        <Box sx={{ display: "flex", flexDirection: "column", gap: 2 }}>
          <TextField label="Manager Name" fullWidth size="small" value={name} onChange={(e) => setName(e.target.value)} />
          <TextField label="Station Location" fullWidth size="small" value={stationLocation} onChange={(e) => setStationLocation(e.target.value)} />
          <TextField label="Phone Number" fullWidth size="small" value={phone} onChange={(e) => setPhone(e.target.value)} />
          <TextField label="Email" fullWidth size="small" value={email} onChange={(e) => setEmail(e.target.value)} />
          <TextField label="Password" type="password" fullWidth size="small" value={password} onChange={(e) => setPassword(e.target.value)} />
        </Box>

        {/* Submit Button */}
        <Box sx={{ display: "flex", justifyContent: "flex-end", mt: 3 }}>
          <Button variant="contained" onClick={handleSubmit}>
            Add Manager
          </Button>
        </Box>
      </Box>
    </Modal>
  );
};

export default AddManagerModal;
