import React, { useEffect, useState } from "react";
import { Box, Button, Typography, TextField, InputAdornment, IconButton } from "@mui/material";
import SearchIcon from "@mui/icons-material/Search";
import EqualizerIcon from "@mui/icons-material/Tune";
import CustomTable, { Column } from "../../components/CustomTable";
import AddManagerModal from "../../pages/AddManagerModal";
import EditUserModal from "../EditUserModal";
import { useDispatch, useSelector } from "react-redux";
import { fetchManagerList, addManager,updateManager,deleteManager } from "../../redux/slices/managerSlice";
import { RootState, AppDispatch } from "../../redux/store/store";


export default function ManagerList() {
    const dispatch = useDispatch<AppDispatch>();
    const { managers, isLoading } = useSelector((state: RootState) => state.managerReducer);

    const [search, setSearch] = useState("");
    const [addButtonModal, setAddButtonModal] = useState(false);
    const [modalOpen, setModalOpen] = useState(false);
    const [rowData, setRowData] = useState(null);
    const [viewModal, setViewModal] = useState(false);
    const [deleteModal, setDeleteModal] = useState(false);

    useEffect(() => {
        dispatch(fetchManagerList()); // Fetch data when component mounts
    }, [dispatch]);

  

    // Function to handle adding a manager
    const handleAddManager = async (newManager: { 
        name: string; 
        registeredAddress: string; 
        phone: string; 
        email: string;
        password: string;
    }) => {
        await dispatch(addManager(newManager));
        dispatch(fetchManagerList()); // Refresh list after adding
        handleCloseModal(); // Close modal after adding
    };



    // Function to handle updating a
    const handleUpdateManager = async (updatedManager) => {
        if (!updatedManager || typeof updatedManager !== "object") {
            return;
        }
    
        if (!rowData) {
            return;
        }
    
        const managerId = rowData.id;
    
        if (!updatedManager.managerName || !updatedManager.stationLocation || !updatedManager.phoneNumber) {
            return;
        }
    
        try {
            const response = await dispatch(updateManager({ 
                id: managerId, 
                name: updatedManager.managerName,
                registeredAddress: updatedManager.stationLocation,
                phone: updatedManager.phoneNumber,
            }));
    
            if (response?.payload?.statusCode === 200) {
                await dispatch(fetchManagerList()); // ✅ Refresh list after update
            }
    
            handleCloseModal();
        } catch (error) {
            console.error("❌ Update failed:", error);
        }
    };
    
    
    // Function to handle deleting a manager


    const handleDeleteManager = async () => {
        if (!rowData?.id) {
            console.error("❌ No manager ID found for deletion!");
            return;
        }
    
        try {
           
            const response = await dispatch(deleteManager(rowData.id));
    
            if (response?.payload) {
             
                dispatch(fetchManagerList()); // Refresh list after deletion
            } else {
                console.error("❌ Deletion failed!", response);
            }
        } catch (error) {
            console.error("❌ Error deleting manager:", error);
        }
    
        setDeleteModal(false); // Close delete modal

        handleCloseModal();
    };
    
   
    

    


    // Function to handle search input change
    const handleSearchChange = (event: React.ChangeEvent<HTMLInputElement>) => {
        setSearch(event.target.value);
    };

    // Open the Add Manager Modal
    const handleClickOpen = () => {
        setRowData(null);
        setAddButtonModal(true);
    };

    // Close all modals
    const handleCloseModal = () => {
        setAddButtonModal(false);
        setModalOpen(false);
        setRowData(null);
    };

    // Table columns definition
    const managerColumns: Column[] = [
        { id: "name", label: "Manager Name" },
        { id: "registeredAddress", label: "Station Location" },
        { id: "phone", label: "Phone Number" },
        { id: "action", label: "Action", align: "center" },
    ];

    // Filtered manager list based on search input
    const filteredManagers = managers.filter((manager) =>
        Object.values(manager).some((value) =>
            typeof value === "string" && value.toLowerCase().includes(search.toLowerCase())
        )
    );

    return (
        <>
            {/* Header Section */}
            <Box sx={{ width: "100%", display: "flex", flexDirection: "column", gap: 2, mt: 2 }}>
                <Typography component="h2" variant="h6" sx={{ fontWeight: 600 }}>
                    Managers
                </Typography>
                <Box sx={{ display: "flex", justifyContent: "space-between", alignItems: "center" }}>
                    <TextField
                        variant="outlined"
                        size="small"
                        placeholder="Search"
                        value={search}
                        onChange={handleSearchChange}
                        InputProps={{
                            startAdornment: (
                                <InputAdornment position="start">
                                    <SearchIcon />
                                </InputAdornment>
                            ),
                        }}
                    />
                    <Box sx={{ display: "flex", alignItems: "center", gap: 2 }}>
                        <Button variant="contained" size="medium" onClick={handleClickOpen}>
                            Add Manager
                        </Button>
                        <IconButton>
                            <EqualizerIcon />
                        </IconButton>
                    </Box>
                </Box>
            </Box>

            {/* Table Section */}
            {isLoading ? (
                <Typography>Loading managers...</Typography>
            ) : (
                <CustomTable
                    columns={managerColumns}
                    rows={filteredManagers.map((manager) => ({
                        id: manager.id,
                        name: manager.name,
                        registeredAddress: manager.registeredAddress,
                        phone: manager.phone,
                        action: (
                            <Box sx={{ display: "flex", gap: 1 }}>
                            <Button onClick={() => { setRowData(manager); setModalOpen(true); }}>Edit</Button>
                            <Button onClick={() => { setRowData(manager); setViewModal(true); }}>View</Button> 
                            <Button color="error" onClick={() => { setRowData(manager); setDeleteModal(true); }}>
    Delete
</Button>

                        </Box>
                        ),
                        
                    }))}
                     tableType="managers"
                    setRowData={setRowData}
                    setModalOpen={setModalOpen}
                    setViewModal={setViewModal}
                    viewModal={viewModal}
                    setDeleteModal={setDeleteModal}
                    deleteModal={deleteModal}
                    handleDeleteButton={handleDeleteManager}
                />
            )}

            {/* Modals */}
            <EditUserModal 
    open={modalOpen} 
    handleClose={handleCloseModal} 
    editRow={rowData} 
    handleUpdate={handleUpdateManager}  // Pass function
/>




            <AddManagerModal
                open={addButtonModal}
                handleClose={handleCloseModal}
                handleAddManager={(data) =>
                    handleAddManager({
                        name: data.managerName,
                        registeredAddress: data.stationLocation,
                        phone: data.phoneNumber,
                        email: data.email, 
                        password: data.password,
                    })
                }
            />
        </>
    );
}
