import { createSlice, createAsyncThunk, PayloadAction } from "@reduxjs/toolkit";
import http from "../../lib/https";
import { toast } from "sonner";

// Define TypeScript types
interface Manager {
    id: string;
    name: string;
    email: string;
    phone?: string;
    role: string;
}

interface ManagerState {
    managers: Manager[];
    loading: boolean;
    error: string | null;
}

// Initial state
const initialState: ManagerState = {
    managers: [],
    loading: false,
    error: null,
};

// Fetch Manager List
export const fetchManagerList = createAsyncThunk<Manager[], void, { rejectValue: string }>(
    "fetchManagers",
    async (_, { rejectWithValue }) => {
        try {
            const response = await http.get("manager-list");
			
            if (!response.data?.data) throw new Error("Invalid API response");

            return response.data.data;
        } catch (error: any) {
            toast.error("Error Fetching Managers: " + error);
            return rejectWithValue(
                error?.response?.data?.message || "An error occurred"
            );
        }
    }
);

// Create Manager
export const addManager = createAsyncThunk(
    "addManager",
    async (data, { rejectWithValue }) => {
        try {
          
            const response = await http.post("create-manager", data);
            toast.success("Manager created successfully");

            // ✅ Ensure the response contains the expected data
            if (!response.data || !response.data.data || !response.data.data.id) {
                console.error("❌ ERROR: Missing manager ID in response", response.data);
                throw new Error("Invalid API response: Missing manager ID");
            }

            return response.data.data;
        } catch (error: any) {
            console.error("❌ API Error:", error?.response?.data || error);
            return rejectWithValue(error?.response?.data?.message || "An error occurred");
        }
    }
);

export const updateManager = createAsyncThunk<
    Manager,
    { id: string; name?: string; email?: string; phone?: string; role?: string; registeredAddress?: string },
    { rejectValue: string }
>(
    "updateManager",
    async ({ id, ...managerData }, { rejectWithValue }) => {
        try {
           

            const response = await http.put(`${id}/update-manager`, managerData);

           
            toast.success("Manager updated successfully!");
            return response.data.data; // ✅ Extracting correct response data
        } catch (error: any) {
           
            toast.error("Error updating manager: " + error);
            return rejectWithValue(
                error.response?.data?.message || "An error occurred"
            );
        }
    }
);

// Delete Manager
export const deleteManager = createAsyncThunk<
    string,
    string,
    { rejectValue: string }
>(
    "deleteManager",
    async (id, { rejectWithValue }) => {
        try {
            await http.delete(`/${id}/delete-manager`);
            toast.success("Manager deleted successfully!");
            return id; // Return the ID of the deleted manager
        } catch (error: any) {
            toast.error("Error deleting manager: " + error);
            return rejectWithValue(
                error.response?.data?.message || "An error occurred"
            );
        }
    }
);





// Create Slice
const managerSlice = createSlice({
    name: "fetchManagers",
    initialState,
    reducers: {},
    extraReducers: (builder) => {
        builder
            // Fetch Managers
            .addCase(fetchManagerList.pending, (state) => {
                state.loading = true;
                state.error = null;
            })
            .addCase(
                fetchManagerList.fulfilled,
                (state, action: PayloadAction<Manager[]>) => {
                    state.loading = false;
                    state.managers = action.payload;
                }
            )
            .addCase(fetchManagerList.rejected, (state, action) => {
                state.loading = false;
                state.error = action.payload || "Failed to fetch managers";
            })

            // Add Manager
            .addCase(addManager.pending, (state) => {
                state.loading = true;
            })
            .addCase(addManager.fulfilled, (state, action: PayloadAction<Manager>) => {
                state.loading = false;
                state.managers.push(action.payload);
            })
            .addCase(addManager.rejected, (state, action) => {
                state.loading = false;
            })

            // Update Manager
            .addCase(updateManager.pending, (state) => {
                state.loading = true;
            })
            .addCase(updateManager.fulfilled, (state, action) => {
                state.loading = false;
                const updatedManager = action.payload;
                const index = state.managers.findIndex(m => m.id === updatedManager.id);
                if (index !== -1) {
                    state.managers[index] = { ...state.managers[index], ...updatedManager }; // 🔥 Merge updated fields
                }
            })
            
            .addCase(updateManager.rejected, (state) => {
                state.loading = false;
            })

            // Delete Manager
            // Delete Manager
.addCase(deleteManager.pending, (state) => {
    state.loading = true;
})
.addCase(deleteManager.fulfilled, (state, action) => {
    state.loading = false;
    state.managers = state.managers.filter(manager => manager.id !== action.payload);
})
.addCase(deleteManager.rejected, (state) => {
    state.loading = false;
});

              
    },
});

export default managerSlice.reducer;
